// This file is generated by kconfig_compiler_kf6 from kollision.kcfg.
// All changes you do to this file will be lost.
#ifndef KOLLISIONCONFIG_H
#define KOLLISIONCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KollisionConfig : public KConfigSkeleton
{
  public:

    static KollisionConfig *self();
    ~KollisionConfig() override;

    /**
      Set Whether automatically increasing ball size should be applied.
    */
    static
    void setIncreaseBallSize( bool v )
    {
      if (!self()->isIncreaseBallSizeImmutable())
        self()->mIncreaseBallSize = v;
    }

    /**
      Get Whether automatically increasing ball size should be applied.
    */
    static
    bool increaseBallSize()
    {
      return self()->mIncreaseBallSize;
    }

    /**
      Is Whether automatically increasing ball size should be applied. Immutable
    */
    static
    bool isIncreaseBallSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "IncreaseBallSize" ) );
    }

    /**
      Set Whether sound effects should be played.
    */
    static
    void setEnableSounds( bool v )
    {
      if (!self()->isEnableSoundsImmutable())
        self()->mEnableSounds = v;
    }

    /**
      Get Whether sound effects should be played.
    */
    static
    bool enableSounds()
    {
      return self()->mEnableSounds;
    }

    /**
      Is Whether sound effects should be played. Immutable
    */
    static
    bool isEnableSoundsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "EnableSounds" ) );
    }

  protected:
    KollisionConfig();
    friend class KollisionConfigHelper;


    // game_options
    bool mIncreaseBallSize;

    // sounds
    bool mEnableSounds;
};

#endif

