/********************************************************************************
** Form generated from reading UI file 'preferences.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCES_H
#define UI_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Preferences
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_EnableSounds;
    QCheckBox *kcfg_IncreaseBallSize;
    QHBoxLayout *hboxLayout;
    QLabel *label_2;
    QComboBox *kcfg_GameDifficulty;
    QVBoxLayout *vboxLayout1;
    QLabel *label;
    QSlider *kcfg_Smoothness;

    void setupUi(QWidget *Preferences)
    {
        if (Preferences->objectName().isEmpty())
            Preferences->setObjectName("Preferences");
        Preferences->resize(177, 116);
        vboxLayout = new QVBoxLayout(Preferences);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_EnableSounds = new QCheckBox(Preferences);
        kcfg_EnableSounds->setObjectName("kcfg_EnableSounds");

        vboxLayout->addWidget(kcfg_EnableSounds);

        kcfg_IncreaseBallSize = new QCheckBox(Preferences);
        kcfg_IncreaseBallSize->setObjectName("kcfg_IncreaseBallSize");

        vboxLayout->addWidget(kcfg_IncreaseBallSize);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_2 = new QLabel(Preferences);
        label_2->setObjectName("label_2");

        hboxLayout->addWidget(label_2);

        kcfg_GameDifficulty = new QComboBox(Preferences);
        kcfg_GameDifficulty->addItem(QString());
        kcfg_GameDifficulty->addItem(QString());
        kcfg_GameDifficulty->addItem(QString());
        kcfg_GameDifficulty->setObjectName("kcfg_GameDifficulty");

        hboxLayout->addWidget(kcfg_GameDifficulty);


        vboxLayout->addLayout(hboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        label = new QLabel(Preferences);
        label->setObjectName("label");

        vboxLayout1->addWidget(label);

        kcfg_Smoothness = new QSlider(Preferences);
        kcfg_Smoothness->setObjectName("kcfg_Smoothness");
        kcfg_Smoothness->setOrientation(Qt::Horizontal);

        vboxLayout1->addWidget(kcfg_Smoothness);


        vboxLayout->addLayout(vboxLayout1);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(kcfg_GameDifficulty);
        label->setBuddy(kcfg_Smoothness);
#endif // QT_CONFIG(shortcut)

        retranslateUi(Preferences);

        QMetaObject::connectSlotsByName(Preferences);
    } // setupUi

    void retranslateUi(QWidget *Preferences)
    {
        kcfg_EnableSounds->setText(tr2i18n("Enable &sounds", nullptr));
        kcfg_IncreaseBallSize->setText(tr2i18n("Enable automatically &increasing ball size", nullptr));
        label_2->setText(tr2i18n("&Difficulty:", nullptr));
        kcfg_GameDifficulty->setItemText(0, tr2i18n("Easy", "Difficulty level"));
        kcfg_GameDifficulty->setItemText(1, tr2i18n("Medium", "Difficulty level"));
        kcfg_GameDifficulty->setItemText(2, tr2i18n("Hard", "Difficulty level"));

        label->setText(tr2i18n("&Animation smoothness:", nullptr));
        (void)Preferences;
    } // retranslateUi

};

namespace Ui {
    class Preferences: public Ui_Preferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCES_H

